import { defineComponent, onMounted, reactive, watch } from 'vue';
import styles from './index.module.less';
import { NButton, NModal, NScrollbar, NSpace, NSpin } from 'naive-ui';
import CardType from '/src/components/card-type';
import AttendClass from '/src/views/prepare-lessons/model/attend-class';
import { usePrepareStore } from '/src/store/modules/prepareLessons';
import TheEmpty from '/src/components/TheEmpty';
import { queryCourseware } from '../../../api';

export default defineComponent({
  name: 'courseware-modal',
  setup() {
    const prepareStore = usePrepareStore();
    const forms = reactive({
      loadingStatus: false,
      showAttendClass: false
    });

    const getList = async () => {
      forms.loadingStatus = true;
      try {
        // 判断是否有选择对应的课件
        if (!prepareStore.getSelectKey) return;
        const { data } = await queryCourseware({
          coursewareDetailKnowledgeId: prepareStore.getSelectKey,
          lessonCoursewareId: prepareStore.getLessonCoursewareId,
          lessonCoursewareDetailId: prepareStore.getLessonCoursewareDetailId,
          pag: 1,
          rows: 99
        });
        const tempRows = data.rows || [];
        const temp: any = [];
        tempRows.forEach((row: any) => {
          temp.push({
            id: row.id,
            coverImg: row.coverImg,
            type: row.materialType,
            title: row.materialName,
            isCollect: !!row.favoriteFlag,
            isSelected: row.source === 'PLATFORM' ? true : false,
            content: row.content
          });
        });

        prepareStore.setCoursewareList(temp || []);
      } catch {
        //
      }
      forms.loadingStatus = false;
    };

    // 监听选择的key
    watch(
      () => prepareStore.getSelectKey,
      () => {
        getList();
      }
    );

    onMounted(() => {
      getList();
    });
    return () => (
      <div class={styles.coursewareModal}>
        <div class={styles.btnGroup}>
          <NSpace>
            <NButton type="default">编辑</NButton>
          </NSpace>

          <NSpace>
            <NButton type="default">预览</NButton>
            <NButton
              type="primary"
              onClick={() => (forms.showAttendClass = true)}>
              开始上课
            </NButton>
          </NSpace>
        </div>

        <NScrollbar class={styles.listContainer}>
          <NSpin show={forms.loadingStatus}>
            <div class={styles.list}>
              {prepareStore.getCoursewareList.map((item: any) => (
                <CardType isShowCollect={false} item={item} />
              ))}
            </div>
            {!forms.loadingStatus &&
              prepareStore.getCoursewareList.length <= 0 && <TheEmpty />}
          </NSpin>
        </NScrollbar>

        <NModal
          v-model:show={forms.showAttendClass}
          preset="card"
          showIcon={false}
          class={['modalTitle background', styles.attendClassModal]}
          title={'选择班级'}
          blockScroll={false}>
          <AttendClass onClose={() => (forms.showAttendClass = false)} />
        </NModal>
      </div>
    );
  }
});
