import { defineComponent, onMounted, reactive, ref } from 'vue';
import styles from './index.module.less';
import { NButton, NInput, NSelect, NSpace } from 'naive-ui';
import { resourceTypeArray } from '/src/utils/searchArray';
import { useCatchStore } from '/src/store/modules/catchData';
import { useDebounceFn } from '@vueuse/core';

export default defineComponent({
  name: 'resource-search-group',
  emits: ['search'],
  setup(props, { emit }) {
    const catchStore = useCatchStore();
    const forms = reactive({
      type: '', //
      keyword: '',
      bookVersionId: null,
      subjectId: null
    });
    const resourceList = ref([] as any);

    const onSearch = () => {
      emit('search', forms);
    };

    const debouncedRequest = useDebounceFn(() => onSearch(), 500);

    onMounted(async () => {
      resourceList.value = [
        {
          label: '全部',
          value: ''
        },
        ...resourceTypeArray
      ];
      // 获取教材分类列表
      await catchStore.getMusicSheetCategory();
      // 获取声部列表
      await catchStore.getSubjects();
    });
    return () => (
      <>
        <div class={styles.searchGroup}>
          <NSpace size="small" class={styles.btnType}>
            {resourceList.value.map((item: any) => (
              <NButton
                type={forms.type === item.value ? 'primary' : 'default'}
                secondary={forms.type === item.value ? false : true}
                round
                size="small"
                focusable={false}
                onClick={() => {
                  forms.type = item.value;
                  debouncedRequest();
                }}>
                {item.label}
              </NButton>
            ))}
          </NSpace>

          <div class={styles.searchSelect}>
            <NSelect
              placeholder="教材"
              options={catchStore.getMusicCategories}
              clearable
              labelField="name"
              valueField="id"
              v-model:value={forms.bookVersionId}
              onUpdate:value={() => {
                onSearch();
              }}
            />
            <NSelect
              placeholder="乐器"
              options={catchStore.getSubjectList}
              clearable
              labelField="name"
              valueField="id"
              v-model:value={forms.subjectId}
              onUpdate:value={() => {
                onSearch();
              }}
            />
          </div>

          <NInput
            type="text"
            placeholder="请输入搜索关键词"
            clearable
            v-model:value={forms.keyword}
            class={styles.inputSearch}
            onKeyup={(e: KeyboardEvent) => {
              if (e.code === 'Enter') {
                debouncedRequest();
              }
            }}
            onClear={() => {
              forms.keyword = '';
              debouncedRequest();
            }}>
            {{
              prefix: () => (
                <span
                  class={'icon-search-input'}
                  onClick={() => debouncedRequest()}></span>
              )
            }}
          </NInput>
        </div>
      </>
    );
  }
});
