import { defineComponent, reactive } from 'vue';
import styles from './index.module.less';
import { NTabs, NTabPane, NModal } from 'naive-ui';
import ShareResources from './components/share-resources';
import MyResources from './components/my-resources';
import MyCollect from './components/my-collect';
import { usePrepareStore } from '/src/store/modules/prepareLessons';
import SelectMusic from '../../model/select-music';

export default defineComponent({
  name: 'resource-main',
  setup() {
    const prePareStore = usePrepareStore();
    const forms = reactive({
      selectMusicStatus: false
    });
    return () => (
      <div class={styles['resource-main']}>
        <NTabs
          animated
          defaultValue="shareResources"
          paneClass={styles.paneTitle}
          paneWrapperClass={styles.paneWrapperContainer}>
          {{
            suffix: () => (
              <div
                class={styles.iconScreen}
                onClick={() => (prePareStore.coursewareFullScreen = true)}>
                <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24">
                  <g fill="none">
                    <path
                      d="M5 6a1 1 0 0 1 1-1h2a1 1 0 0 0 0-2H6a3 3 0 0 0-3 3v2a1 1 0 0 0 2 0V6zm0 12a1 1 0 0 0 1 1h2a1 1 0 1 1 0 2H6a3 3 0 0 1-3-3v-2a1 1 0 1 1 2 0v2zM18 5a1 1 0 0 1 1 1v2a1 1 0 1 0 2 0V6a3 3 0 0 0-3-3h-2a1 1 0 1 0 0 2h2zm1 13a1 1 0 0 1-1 1h-2a1 1 0 1 0 0 2h2a3 3 0 0 0 3-3v-2a1 1 0 1 0-2 0v2z"
                      fill="#198CFE"></path>
                  </g>
                </svg>
              </div>
            ),
            default: () => (
              <>
                <NTabPane
                  name="shareResources"
                  tab="共享资源"
                  displayDirective="show:lazy">
                  <ShareResources />
                </NTabPane>
                <NTabPane
                  name="myResources"
                  tab="我的资源"
                  displayDirective="show:lazy">
                  <MyResources />
                </NTabPane>
                <NTabPane
                  name="myCollect"
                  tab="我的收藏"
                  displayDirective="show:lazy">
                  <MyCollect />
                </NTabPane>
              </>
            )
          }}
        </NTabs>

        <NModal
          v-model:show={forms.selectMusicStatus}
          class={['modalTitle', styles.selectMusicModal]}
          preset="card"
          title={'选择曲目'}>
          <SelectMusic />
        </NModal>
      </div>
    );
  }
});
